import numpy as np


def extractMatrix(matrixLadder: np.ndarray, x: int, y: int) -> tuple[np.ndarray, int, int]:
    # Initial clipping to get the 9x9 matrix around (x, y)
    xLower = np.clip(x - 4, a_min=0, a_max=matrixLadder.shape[0] - 9)
    xUpper = np.clip(x + 5, a_min=0, a_max=matrixLadder.shape[0])
    yLower = np.clip(y - 4, a_min=0, a_max=matrixLadder.shape[1] - 9)
    yUpper = np.clip(y + 5, a_min=0, a_max=matrixLadder.shape[1])

    matrix = matrixLadder[xLower:xUpper, yLower:yUpper]
    xxArgMax, yyArgMax = np.unravel_index(matrix.argmax(), matrix.shape)

    # Check if max charge pixel is not at the center and re-center if necessary
    if (xxArgMax, yyArgMax) != (4, 4):
        # Calculate how much to roll in each direction to center the max charge
        x_offset = 4 - xxArgMax
        y_offset = 4 - yyArgMax

        # Adjust the x and y lower bounds to center the max charge
        xLower = np.clip(x + x_offset - 4, a_min=0, a_max=matrixLadder.shape[0] - 9)
        yLower = np.clip(y + y_offset - 4, a_min=0, a_max=matrixLadder.shape[1] - 9)

        # Recalculate the matrix now centered around the max charge
        matrix = matrixLadder[xLower:xLower+9, yLower:yLower+9]

    return matrix, xLower, yLower
